# cat /filecoin/worker.log |grep commit|egrep -v "validate|seal_commit"
# {"level":"info","ts":"2021-07-26T06:42:40.492+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:42:40.492+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(1)"}
# {"level":"info","ts":"2021-07-26T06:44:00.190+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:44:00.190+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(2)"}
# {"level":"info","ts":"2021-07-26T06:47:37.908+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:47:37.908+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(33)"}
# {"level":"info","ts":"2021-07-26T06:47:44.269+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:47:44.269+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(24)"}
# {"level":"info","ts":"2021-07-26T06:47:46.253+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:47:46.253+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(42)"}
# {"level":"info","ts":"2021-07-26T06:48:01.563+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:48:01.563+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(68)"}
# {"level":"info","ts":"2021-07-26T06:48:06.264+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:48:06.264+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(59)"}
# {"level":"info","ts":"2021-07-26T06:48:07.759+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:48:07.759+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(6)"}
# {"level":"info","ts":"2021-07-26T06:51:53.697+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:51:53.697+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(15)"}
# {"level":"info","ts":"2021-07-26T06:51:53.704+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:51:53.704+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(77)"}
# {"level":"info","ts":"2021-07-26T06:51:53.705+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T06:51:53.705+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(50)"}
# {"level":"info","ts":"2021-07-26T07:00:05.507+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T07:00:05.509+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(81)"}
# {"level":"info","ts":"2021-07-26T09:43:17.874+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(1)"}
# {"level":"info","ts":"2021-07-26T09:43:17.877+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:43:18.067+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T09:43:18.070+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T09:52:19.388+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(2)"}
# {"level":"info","ts":"2021-07-26T09:52:19.388+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:54:12.837+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(42)"}
# {"level":"info","ts":"2021-07-26T09:54:12.837+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:55:32.791+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(6)"}
# {"level":"info","ts":"2021-07-26T09:55:32.791+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:56:33.704+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(15)"}
# {"level":"info","ts":"2021-07-26T09:56:33.704+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:56:50.984+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(59)"}
# {"level":"info","ts":"2021-07-26T09:56:50.984+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:57:15.841+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(24)"}
# {"level":"info","ts":"2021-07-26T09:57:15.841+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:57:47.256+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(33)"}
# {"level":"info","ts":"2021-07-26T09:57:47.256+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T09:59:20.532+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(50)"}
# {"level":"info","ts":"2021-07-26T09:59:20.532+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T10:00:40.759+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(68)"}
# {"level":"info","ts":"2021-07-26T10:00:40.759+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T10:01:41.059+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T10:01:41.059+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T10:01:41.132+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T10:01:41.132+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T10:03:32.768+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(77)"}
# {"level":"info","ts":"2021-07-26T10:03:32.768+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T10:06:49.621+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(81)"}
# {"level":"info","ts":"2021-07-26T10:06:49.621+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T10:17:51.254+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T10:17:51.254+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T10:17:51.321+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T10:17:51.321+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T10:32:33.939+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T10:32:33.939+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T10:32:34.001+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T10:32:34.001+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T10:48:24.629+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T10:48:24.629+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T10:48:24.705+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T10:48:24.705+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T11:03:24.927+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T11:03:24.927+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T11:03:24.996+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T11:03:24.996+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T11:17:54.070+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T11:17:54.070+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T11:17:54.158+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T11:17:54.158+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T11:32:51.611+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T11:32:51.611+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T11:32:51.672+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T11:32:51.672+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T11:48:10.747+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T11:48:10.747+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T11:48:10.813+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T11:48:10.813+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T12:02:45.860+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T12:02:45.860+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T12:02:45.924+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T12:02:45.925+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T12:02:54.548+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T12:02:54.549+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(89)"}
# {"level":"info","ts":"2021-07-26T12:15:09.848+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T12:15:09.848+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(83)"}
# {"level":"info","ts":"2021-07-26T12:19:33.138+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T12:19:33.138+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T12:19:33.204+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T12:19:33.205+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T12:30:47.774+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:1295","msg":"generate_data_commitment: start"}
# {"level":"info","ts":"2021-07-26T12:30:47.775+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:1319","msg":"generate_data_commitment: finish"}
# {"level":"info","ts":"2021-07-26T12:31:47.335+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:1295","msg":"generate_data_commitment: start"}
# {"level":"info","ts":"2021-07-26T12:31:47.337+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:1319","msg":"generate_data_commitment: finish"}
# {"level":"info","ts":"2021-07-26T12:32:11.153+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:1295","msg":"generate_data_commitment: start"}
# {"level":"info","ts":"2021-07-26T12:32:11.154+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:1319","msg":"generate_data_commitment: finish"}
# {"level":"info","ts":"2021-07-26T12:35:11.681+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T12:35:11.681+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(87)"}
# {"level":"info","ts":"2021-07-26T12:37:49.702+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T12:37:49.702+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T12:37:50.763+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T12:37:50.763+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T12:52:25.680+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T12:52:25.680+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T13:15:08.419+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T13:15:08.419+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(84)"}
# {"level":"info","ts":"2021-07-26T13:34:07.845+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T13:34:07.845+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(91)"}
# {"level":"info","ts":"2021-07-26T13:54:06.871+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T13:54:06.871+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(93)"}
# {"level":"info","ts":"2021-07-26T14:13:37.900+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T14:13:37.900+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(92)"}
# {"level":"info","ts":"2021-07-26T14:34:01.270+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T14:34:01.272+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(94)"}
# {"level":"info","ts":"2021-07-26T14:53:38.137+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T14:53:38.139+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(95)"}
# {"level":"info","ts":"2021-07-26T15:11:09.700+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(89)"}
# {"level":"info","ts":"2021-07-26T15:11:09.701+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T15:11:09.891+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T15:11:09.893+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T15:13:30.198+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T15:13:30.198+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(96)"}
# {"level":"info","ts":"2021-07-26T15:14:30.953+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T15:14:30.953+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(100)"}
# {"level":"info","ts":"2021-07-26T15:22:22.494+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(83)"}
# {"level":"info","ts":"2021-07-26T15:22:22.495+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T15:30:19.823+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T15:30:19.823+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T15:30:19.907+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T15:30:19.907+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T15:32:37.475+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T15:32:37.475+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(101)"}
# {"level":"info","ts":"2021-07-26T15:43:07.288+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(87)"}
# {"level":"info","ts":"2021-07-26T15:43:07.289+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T15:49:20.211+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T15:49:20.211+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T15:49:20.290+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T15:49:20.291+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T16:07:12.501+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T16:07:12.502+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T16:22:07.132+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(84)"}
# {"level":"info","ts":"2021-07-26T16:22:07.132+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T16:22:07.317+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T16:22:07.317+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T16:38:12.095+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T16:38:12.095+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T16:41:36.473+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(91)"}
# {"level":"info","ts":"2021-07-26T16:41:36.473+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T16:41:36.605+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T16:41:36.606+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T16:57:27.554+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T16:57:27.554+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T17:04:03.675+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(93)"}
# {"level":"info","ts":"2021-07-26T17:04:03.675+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T17:04:03.837+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T17:04:03.837+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T17:12:39.275+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T17:12:39.275+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(97)"}
# {"level":"info","ts":"2021-07-26T17:21:10.756+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T17:21:10.756+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T17:23:50.851+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(92)"}
# {"level":"info","ts":"2021-07-26T17:23:50.851+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T17:23:51.060+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T17:23:51.061+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T17:32:39.450+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T17:32:39.450+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(85)"}
# {"level":"info","ts":"2021-07-26T17:41:22.833+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T17:41:22.833+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T17:44:37.444+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(94)"}
# {"level":"info","ts":"2021-07-26T17:44:37.444+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T17:44:37.610+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T17:44:37.611+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T17:52:37.881+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T17:52:37.881+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(82)"}
# {"level":"info","ts":"2021-07-26T18:01:42.782+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T18:01:42.782+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T18:09:28.783+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(95)"}
# {"level":"info","ts":"2021-07-26T18:09:28.784+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T18:09:28.917+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T18:09:28.917+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T18:19:38.399+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T18:19:38.399+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(86)"}
# {"level":"info","ts":"2021-07-26T18:26:23.763+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:320","msg":"seal_pre_commit_phase2:finish"}
# {"level":"info","ts":"2021-07-26T18:26:23.763+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:295","msg":"seal_pre_commit_phase2: finish"}
# {"level":"info","ts":"2021-07-26T18:33:59.977+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(100)"}
# {"level":"info","ts":"2021-07-26T18:33:59.977+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:196","msg":"seal_pre_commit_phase1:finish: SectorId(96)"}
# {"level":"info","ts":"2021-07-26T18:33:59.977+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T18:33:59.977+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:246","msg":"seal_pre_commit_phase1: finish"}
# {"level":"info","ts":"2021-07-26T18:34:00.313+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:264","msg":"seal_pre_commit_phase2: start"}
# {"level":"info","ts":"2021-07-26T18:34:00.314+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:211","msg":"seal_pre_commit_phase2:start"}
# {"level":"info","ts":"2021-07-26T18:39:09.239+0800","logger":"filcrypto::proofs::api","caller":"src/proofs/api.rs:213","msg":"seal_pre_commit_phase1: start"}
# {"level":"info","ts":"2021-07-26T18:39:09.239+0800","logger":"filecoin_proofs::api::seal","caller":"/root/.cargo/registry/src/github.com-1ecc6299db9ec823/filecoin-proofs-8.0.2/src/api/seal.rs:68","msg":"seal_pre_commit_phase1:start: SectorId(88)"}

import os
import json

worker_log=os.path.abspath(".\\Calibnet\\pc1.log")
if (os.name != 'nt'): 
    sectors_log_dir=os.path.abspath("./worker.precommit.log")
    
from lotusops.speedtest.jsonformat import makeReport,printReports,analyzeReports

if __name__ == "__main__":
    reports = makeReport(worker_log,filters=["seal_pre_commit_phase1","SectorId"])
    printReports(reports)
    print("#################################")
    analyzeReports(reports)