# from __future__ import absolute_import

events=[
        "SectorStartCC",
        "SectorPacked",
        "SectorTicket",
        "SectorPreCommit1",
        "SectorPreCommit2",
        "SectorPreCommitBatch",
        "SectorPreCommitBatchSent",
        "SectorPreCommitLanded",
        "SectorSeedReady",
        "SectorCommitted",
        "SectorSubmitCommitAggregate",
        "SectorCommitAggregateSent",
        "SectorProving",
        "SectorFinalized",
        "SectorSealPreCommit1Failed",
        "SectorRetrySealPreCommit1",
]